import os
import dotenv
import argparse
from .constants import (DEFAULT_VERSION, DEFAULT_THREAD_UPLOAD, RETRY_DELAY_SECONDS)

class Config:
    def __init__(self, 
                api_url: str = None,
                token: str = None,
                study_name: str = None,
                number_threads: int = DEFAULT_THREAD_UPLOAD,
                retry_delay_seconds: int = RETRY_DELAY_SECONDS) -> None:

        # eviroment config
        self.api_url = api_url
        self.version = DEFAULT_VERSION # default 
        self.token = token
        self.study_name = study_name
        self.number_threads = number_threads
        self.retry_delay_seconds = retry_delay_seconds
    
    



import asyncio
from .config import Config
from .uploader_service import UploaderService
from .constants import (DEFAULT_SKIP_EXTENSION)

def upload_folder(config: Config, folder_path: str, include_folder: bool = False, parent_folder_name: str = None, skip_extensions: list[str] = ['.log']):
    try:
        if len(skip_extensions) == 0:
            skip_extensions = DEFAULT_SKIP_EXTENSION
        uploader_service = UploaderService(config)
        asyncio.run(uploader_service.upload_folder(folder_path, include_folder, parent_folder_name, skip_extensions))
    except Exception as e:
        print("An error occurred during the upload Folder:", str(e))

def upload_file(config: Config, file_path: str):
    try:
        uploader_service = UploaderService(config)
        uploader_service.WRITE_LOG_UPLOAD = False
        uploader_service.SKIP_CHECK_UPLOADED = True
        asyncio.run(uploader_service.upload_file(file_path, False))
    except Exception as e:
        print("An error occurred during the upload File:", str(e))


class UploadErrorException(Exception):
    def __init__(self, file_path, key, message=None):
        self.file_path = file_path
        self.key = key
        self.message = message or f"Failed to upload {file_path}"
        super().__init__(self.message)